@@ -24,4 +24,4 @@ class BaseYarnCommand(BaseCommand):
             raise YarnNotInstalled()
 
     def _install(self, args):
-        yarn_adapter.install(settings.YARN_INSTALLED_APPS, *args)
+        return yarn_adapter.install(settings.YARN_INSTALLED_APPS, *args)
