@@ -35,6 +35,8 @@ class YarnAdapter(object):
 
     def install(self, packages, *options):
         """Install packages from yarn"""
+        self.call_yarn(["init", "--yes"])
+        self.call_yarn(["config", "set", "nodeLinker", "node-modules"])
         return self.call_yarn(['add'] + list(options) + list(packages))
 
     def _accumulate_dependencies(self, data):
